@@ -15,9 +15,8 @@
 bond <- function(ytm = 0.05, C = 0.05, T2M = 1, m = 2, output = "price") {
   df <- dplyr::tibble(t.years=seq(from=1/m,to=T2M,by=1/m), cf=rep(x=C*100/m,times=T2M*m)) %>%
     dplyr::mutate(t.periods=m*t.years,
-                  cf=replace(cf,t.years==T2M,C*100/m+100)) %>% dplyr::as_tibble() %>%
-    dplyr::mutate(disc.factor=1/((1+ytm/m)^t.periods),pv=cf*disc.factor)
-  # same as previous function above this line
+                  cf=replace(cf,t.years==T2M,C*100/m+100),
+                  disc.factor=1/((1+ytm/m)^t.periods),pv=cf*disc.factor)
   price <- sum(df$pv)
   df <- df %>% dplyr::mutate(duration=(pv*t.years)/price)
   if (output == "price") {return(sum(df$pv))}
